@@ -23,7 +23,7 @@ public:
   void createConfig(QDialog *, QVBoxLayout*);
 
   bool busy();
-  void processRequestOverview(const QGeoBoundingBox &, const int);
+  void processRequestOverview(const QGeoBoundingBox &, const int, const int);
   void processRequestInfo(const QString &);
   void processRequestDetail(const QString &);
 
