@@ -9,10 +9,10 @@ class CustomPixmap: public QPixmap {
  public:
   enum State { Normal, Highlight, Greyscale };
   
-  CustomPixmap(QSvgRenderer *, const QStringList &, int = 0);
-  CustomPixmap(const QStringList &, int = 0, State = Normal);
+  CustomPixmap(QSvgRenderer *, const QStringList &, int = 0, qreal = 0.0);
+  CustomPixmap(const QStringList &, int = 0, State = Normal, qreal = 0.0);
   ~CustomPixmap();
-  bool is(const QString &, State);
+  bool is(const QString &, State, qreal = 0.0);
   QPoint offset();
   static QSize prepare(QSvgRenderer *, const QString &, int);
 
@@ -22,6 +22,7 @@ class CustomPixmap: public QPixmap {
   QString m_name;
   State m_state;
   QPoint m_offset;
+  qreal m_angle;
 };
 
 #endif // CUSTOM_PIXMAP_H
