@@ -69,6 +69,14 @@ CustomWindow::CustomWindow(const QString &name, QWidget *parent) :
     connect(backAction, SIGNAL(triggered()), this, SLOT(close()));
     addAction(backAction );
   }
+
+  // under belle the "Exit" button is replaced with a back arrow
+  // just connect an empty action, anyway ...
+  if(!parent) {
+    QAction *hideAction = new QAction( this );
+    hideAction->setSoftKeyRole( QAction::NegativeSoftKey );
+    addAction(hideAction );
+  }
 #endif
 
   setAttribute(Qt::WA_DeleteOnClose);
@@ -290,9 +298,10 @@ void CustomWindow::toggleFullscreen() {
 }
 
 QAction *CustomWindow::addMenuEntry(const QString &title, 
-		QObject *target, const char *slot) {
+	    QObject *target, const char *slot, QMenu *menu) {
   QAction *action = new QAction(title, this);
   connect(action, SIGNAL(triggered()), target, slot);
-  menuBar()->addAction(action);
+  if(menu) menu->addAction(action);
+  else     menuBar()->addAction(action);
   return action;
 }
