@@ -54,9 +54,6 @@ void MainWindow::createMenu() {
 
   addMenuEntry(tr("&About"), this, SLOT(about()));
 
-  m_motdAction = addMenuEntry(tr("&MotD"), this, SLOT(motd()));
-  m_motdAction->setEnabled(false);
-
   addMenuEntry(tr("&Settings"), this, SLOT(settingsdialog()));
 
   /* create a submenu for the plugin selection */  
@@ -68,6 +65,13 @@ void MainWindow::createMenu() {
   m_ActionToolProjection = 
     ToolProjection::registerMenu(toolsMenu, this, SLOT(launchToolProjection()));
   m_ActionToolProjection->setEnabled(false);
+
+  m_motdAction = addMenuEntry(tr("&MotD"), this, SLOT(motd()), toolsMenu);
+  m_motdAction->setEnabled(false);
+
+#if defined(Q_OS_SYMBIAN)
+  addMenuEntry(tr("E&xit"), this, SLOT(close()));
+#endif
 }
 
 static void drop(QXmlStreamReader &xml) {
