@@ -27,7 +27,9 @@ QTM_USE_NAMESPACE
 // handhelds
 #define CACHELIST_LIMIT 99
 
-// #define WORKAROUND_CONTAINS
+#ifdef Q_OS_SYMBIAN
+#define WORKAROUND_CONTAINS
+#endif
 
 class MapWidget : public QGraphicsGeoMap {
   Q_OBJECT;
